unit DeviceSpec;

interface
type
    TPowerUPType = (VddBeforVpp,
                    VppBeforVdd);

    TProgrammingType = (Internal08,
                        Internal18,
                        External08,
                        External18,
                        External18a);

    TEraseType = (BulkEraseF509,
                  BulkEraseF675,
                  BulkEraseF683,
                  BulkEraseF84,
                  BulkEraseF648A,
                  ChipEraseF88,
                  ChipEraseF77);

    TDoubleWord = array [0..1] of Word;

    TDeviceSpec = record
        DeviceName : string;
        DeviceIDWord : Word;
        UserIDAddress : Word;
        PowerUPType : TPowerUPType;
        ProgramMemoryMask : Word;
        ProgramMemorySize : Integer;
        EEDataMemorySize : Integer;
        ConfigDispSize : Integer;
        ConfigAddress1 : Word;
        ConfigAddress2 : Word;
        ConfigMask1 : Word;
        ConfigMask2 : Word;
        CalibAddress : TDoubleWord;
        CalibMask : TDoubleWord;
        ProgrammingType : TProgrammingType;
        ProgrammingTypeC : TProgrammingType;
        ProgrammingWait : Byte;
        ProgrammingWaitD : Byte;
        ProgrammingWaitC : Byte;
        ProgrammingLatch : Byte;
        EraseType : TEraseType;
        EraseWait : Byte;
        PaMask : Word;
    end;

    TEEWriteType18 = (PollWRbit, FixWaitTime);

    TEraseCommand18 = (Command80, Command3F8F);

    TDeviceSpec18 = record
        DeviceName : string;
        DeviceIDWord : Word;
        ProgramMemorySize : Integer;
        EEDataMemorySize : Integer;
        WriteBufferSize : Integer;
        ConfigMask : array[0..13] of Byte;
        ConfigValue : array[0..13] of Byte;
        EraseCommand : TEraseCommand18;
        EEWriteType : TEEWriteType18;
        PanelNum : Integer;
        PanelSize : Integer;
        ProgrammingWaitP : Byte;
        ProgrammingWaitD : Byte;
        ProgrammingWaitC : Byte;
        ProgrammingWaitID : Byte;
        EraseWait : Byte;
    end;

    TDeviceGroup=(PIC16,PIC18);

var
    DeviceGroup : TDeviceGroup=PIC16;

    DeviceSpecList : array[0..70] of TDeviceSpec =(
        (
        DeviceName : '<PIC18F>';
        DeviceIDWord : $FFFF),
        (
        DeviceName : 'PIC10F200';
        DeviceIDWord : 0;
        UserIDAddress : $100;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 256;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $01FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($FF, $104);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FEB),
        (
        DeviceName : 'PIC10F202';
        DeviceIDWord : 0;
        UserIDAddress : $200;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 512;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $03FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($1FF, $204);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FEB),
        (
        DeviceName : 'PIC10F204';
        DeviceIDWord : 0;
        UserIDAddress : $100;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 256;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $01FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($FF, $104);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FEB),
        (
        DeviceName : 'PIC10F206';
        DeviceIDWord : 0;
        UserIDAddress : $200;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 512;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $03FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($1FF, $204);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FEB),
        (
        DeviceName : 'PIC10F220';
        DeviceIDWord : 0;
        UserIDAddress : $100;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 256;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $01FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($FF, $104);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FEB),
        (
        DeviceName : 'PIC10F222';
        DeviceIDWord : 0;
        UserIDAddress : $200;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 512;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $03FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($1FF, $204);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FEB),
        (
        DeviceName : 'PIC12F508';
        DeviceIDWord : 0;
        UserIDAddress : $200;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 512;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $03FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($1FF, $204);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FE8),
        (
        DeviceName : 'PIC12F509';
        DeviceIDWord : 0;
        UserIDAddress : $400;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $07FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($3FF, $404);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FE8),
        (
        DeviceName : 'PIC12F510';
        DeviceIDWord : 0;
        UserIDAddress : $400;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 0;
        ConfigDispSize : 5;
        ConfigAddress1 : $07FF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : ($3FF, $404);
        CalibMask : ($0FFF, $0FFF);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FE8),
        (
        DeviceName : 'PIC12F609';
        DeviceIDWord : $2240;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 0;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : External18a;
        ProgrammingTypeC : External18a;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12F610';
        DeviceIDWord : $2260;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 0;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : External18a;
        ProgrammingTypeC : External18a;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12F615';
        DeviceIDWord : $2180;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 0;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : External18a;
        ProgrammingTypeC : External18a;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12F616';
        DeviceIDWord : $1240;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 0;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : External18a;
        ProgrammingTypeC : External18a;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12HV609';
        DeviceIDWord : $2280;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 0;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : External18a;
        ProgrammingTypeC : External18a;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12HV610';
        DeviceIDWord : $22A0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 0;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : External18a;
        ProgrammingTypeC : External18a;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12HV615';
        DeviceIDWord : $21A0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 0;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : External18a;
        ProgrammingTypeC : External18a;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12HV616';
        DeviceIDWord : $1260;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 0;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : External18a;
        ProgrammingTypeC : External18a;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12F629';
        DeviceIDWord : $0F80;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $01FF;
        ConfigMask2 : 0;
        CalibAddress : ($3FF, $2007);
        CalibMask : ($3FFF, $3000);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 80;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12F635';
        DeviceIDWord : $0FA0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12F675';
        DeviceIDWord : $0FC0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $01FF;
        ConfigMask2 : 0;
        CalibAddress : ($3FF, $2007);
        CalibMask : ($3FFF, $3000);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 80;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC12F683';
        DeviceIDWord : $0460;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F57';
        DeviceIDWord : 0;
        UserIDAddress : $800;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $0FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 0;
        ConfigDispSize : 4;
        ConfigAddress1 : $0FFF;
        ConfigAddress2 : 0;
        ConfigMask1 : $0FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 0;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF509;
        EraseWait : 100;
        PaMask : $0FF8),
        (
        DeviceName : 'PIC16F630';
        DeviceIDWord : $10C0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $01FF;
        ConfigMask2 : 0;
        CalibAddress : ($3FF, $2007);
        CalibMask : ($3FFF, $3000);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 80;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F676';
        DeviceIDWord : $10E0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $01FF;
        ConfigMask2 : 0;
        CalibAddress : ($3FF, $2007);
        CalibMask : ($3FFF, $3000);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF675;
        EraseWait : 80;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F627';
        DeviceIDWord : $07A0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal18;
        ProgrammingTypeC : Internal18;
        ProgrammingWait : 80;
        ProgrammingWaitD : 80;
        ProgrammingWaitC : 80;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 130;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F628';
        DeviceIDWord : $07C0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal18;
        ProgrammingTypeC : Internal18;
        ProgrammingWait : 80;
        ProgrammingWaitD : 80;
        ProgrammingWaitC : 80;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 130;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F627A';
        DeviceIDWord : $1040;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF648A;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F628A';
        DeviceIDWord : $1060;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF648A;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F648A';
        DeviceIDWord : $1100;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF648A;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F631';
        DeviceIDWord : $1420;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F636';
        DeviceIDWord : $10A0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F639';
        DeviceIDWord : $10A0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F677';
        DeviceIDWord : $1440;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F684';
        DeviceIDWord : $1080;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F685';
        DeviceIDWord : $04A0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F687';
        DeviceIDWord : $1320;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F688';
        DeviceIDWord : $1180;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F689';
        DeviceIDWord : $1340;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F690';
        DeviceIDWord : $1400;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F73';
        DeviceIDWord : $0600;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 0;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 10;
        ProgrammingWaitD : 0;
        ProgrammingWaitC : 10;
        ProgrammingLatch : 2;
        EraseType : ChipEraseF77;
        EraseWait : 255;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F74';
        DeviceIDWord : $0620;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 0;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 10;
        ProgrammingWaitD : 0;
        ProgrammingWaitC : 10;
        ProgrammingLatch : 2;
        EraseType : ChipEraseF77;
        EraseWait : 255;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F76';
        DeviceIDWord : $0640;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 0;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 10;
        ProgrammingWaitD : 0;
        ProgrammingWaitC : 10;
        ProgrammingLatch : 1;
        EraseType : ChipEraseF77;
        EraseWait : 255;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F77';
        DeviceIDWord : $0660;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 0;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External08;
        ProgrammingTypeC : External08;
        ProgrammingWait : 10;
        ProgrammingWaitD : 0;
        ProgrammingWaitC : 10;
        ProgrammingLatch : 2;
        EraseType : ChipEraseF77;
        EraseWait : 255;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F716';
        DeviceIDWord : $1140;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 0;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : External18;
        ProgrammingWait : 20;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F785';
        DeviceIDWord : $1200;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16HV785';
        DeviceIDWord : $1220;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF675;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F818';
        DeviceIDWord : $04C0;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 1024;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : External18;
        ProgrammingWait : 20;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 4;
        EraseType : ChipEraseF88;
        EraseWait : 80;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F819';
        DeviceIDWord : $04E0;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 256;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : External18;
        ProgrammingWait : 20;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 4;
        EraseType : ChipEraseF88;
        EraseWait : 80;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F83';
        DeviceIDWord : 0;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : $200;
        EEDataMemorySize : $40;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 100;
        ProgrammingWaitD : 100;
        ProgrammingWaitC : 100;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 200;
        PaMask : $3FF0),
        (
        DeviceName : 'PIC16F84';
        DeviceIDWord : 0;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : $400;
        EEDataMemorySize : $40;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 100;
        ProgrammingWaitD : 100;
        ProgrammingWaitC : 100;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 200;
        PaMask : $3FF0),
        (
        DeviceName : 'PIC16F84A';
        DeviceIDWord : $0560;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : $400;
        EEDataMemorySize : $40;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal18;
        ProgrammingTypeC : Internal18;
        ProgrammingWait : 40;
        ProgrammingWaitD : 40;
        ProgrammingWaitC : 40;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 80;
        PaMask : $3FF0),
        (
        DeviceName : 'PIC16F87';
        DeviceIDWord : $0720;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : $2008;
        ConfigMask1 : $3FFF;
        ConfigMask2 : $3FFF;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : External18;
        ProgrammingWait : 20;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 4;
        EraseType :ChipEraseF88;
        EraseWait : 80;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F88';
        DeviceIDWord : $0760;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 9;
        ConfigAddress1 : $2007;
        ConfigAddress2 : $2008;
        ConfigMask1 : $3FFF;
        ConfigMask2 : $3FFF;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : External18;
        ProgrammingWait : 20;
        ProgrammingWaitD : 20;
        ProgrammingWaitC : 20;
        ProgrammingLatch : 4;
        EraseType :ChipEraseF88;
        EraseWait : 80;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F873';
        DeviceIDWord : $0960;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal18;
        ProgrammingTypeC : Internal18;
        ProgrammingWait : 40;
        ProgrammingWaitD : 40;
        ProgrammingWaitC : 40;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 80;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F874';
        DeviceIDWord : $0920;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal18;
        ProgrammingTypeC : Internal18;
        ProgrammingWait : 40;
        ProgrammingWaitD : 40;
        ProgrammingWaitC : 40;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 80;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F876';
        DeviceIDWord : $09E0;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal18;
        ProgrammingTypeC : Internal18;
        ProgrammingWait : 40;
        ProgrammingWaitD : 40;
        ProgrammingWaitC : 40;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 80;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F877';
        DeviceIDWord : $09A0;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : Internal18;
        ProgrammingTypeC : Internal18;
        ProgrammingWait : 40;
        ProgrammingWaitD : 40;
        ProgrammingWaitC : 40;
        ProgrammingLatch : 1;
        EraseType : BulkEraseF84;
        EraseWait : 80;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F873A';
        DeviceIDWord : $0E40;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 10;
        ProgrammingWaitD : 80;
        ProgrammingWaitC : 80;
        ProgrammingLatch : 8;
        EraseType : ChipEraseF88;
        EraseWait : 80;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F874A';
        DeviceIDWord : $0E60;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 128;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 10;
        ProgrammingWaitD : 80;
        ProgrammingWaitC : 80;
        ProgrammingLatch : 8;
        EraseType : ChipEraseF88;
        EraseWait : 80;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F876A';
        DeviceIDWord : $0E00;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 10;
        ProgrammingWaitD : 80;
        ProgrammingWaitC : 80;
        ProgrammingLatch : 8;
        EraseType : ChipEraseF88;
        EraseWait : 80;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F877A';
        DeviceIDWord : $0E20;
        UserIDAddress : $2000;
        PowerUPType : VddBeforVpp;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        ConfigDispSize : 8;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : (0, 0);
        CalibMask : (0, 0);
        ProgrammingType : External18;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 10;
        ProgrammingWaitD : 80;
        ProgrammingWaitC : 80;
        ProgrammingLatch : 8;
        EraseType : ChipEraseF88;
        EraseWait : 80;
        PaMask : $3FB0),
        (
        DeviceName : 'PIC16F882';
        DeviceIDWord : $2000;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 2048;
        EEDataMemorySize : 128;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : $2008;
        ConfigMask1 : $3FFF;
        ConfigMask2 : $3FFF;
        CalibAddress : ($2009, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F883';
        DeviceIDWord : $2020;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : $2008;
        ConfigMask1 : $3FFF;
        ConfigMask2 : $3FFF;
        CalibAddress : ($2009, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F884';
        DeviceIDWord : $2040;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : $2008;
        ConfigMask1 : $3FFF;
        ConfigMask2 : $3FFF;
        CalibAddress : ($2009, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F886';
        DeviceIDWord : $2060;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : $2008;
        ConfigMask1 : $3FFF;
        ConfigMask2 : $3FFF;
        CalibAddress : ($2009, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 8;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F887';
        DeviceIDWord : $2080;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : $2008;
        ConfigMask1 : $3FFF;
        ConfigMask2 : $3FFF;
        CalibAddress : ($2009, 0);
        CalibMask : ($3FFF, 0);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 30;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 30;
        ProgrammingLatch : 8;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F913';
        DeviceIDWord : $13E0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F914';
        DeviceIDWord : $13C0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F916';
        DeviceIDWord : $13A0;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF),
        (
        DeviceName : 'PIC16F917';
        DeviceIDWord : $1380;
        UserIDAddress : $2000;
        PowerUPType : VppBeforVdd;
        ProgramMemoryMask : $3FFF;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        ConfigDispSize : 10;
        ConfigAddress1 : $2007;
        ConfigAddress2 : 0;
        ConfigMask1 : $3FFF;
        ConfigMask2 : 0;
        CalibAddress : ($2008, $2009);
        CalibMask : ($3FFF, $3FFF);
        ProgrammingType : Internal08;
        ProgrammingTypeC : Internal08;
        ProgrammingWait : 25;
        ProgrammingWaitD : 60;
        ProgrammingWaitC : 25;
        ProgrammingLatch : 4;
        EraseType : BulkEraseF683;
        EraseWait : 60;
        PaMask : $3FFF)
    );

    DeviceSpecList18 : array[0..20] of TDeviceSpec18 =(
        (
        DeviceName : '<PIC16/12/10F>';
        DeviceIDWord : $FFFF),
        (
        DeviceName : 'PIC18F242';
        DeviceIDWord : $0480;
        ProgramMemorySize : 16384;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : PollWRbit;
        PanelNum : 2;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F252';
        DeviceIDWord : $0400;
        ProgramMemorySize : 32768;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : PollWRbit;
        PanelNum : 4;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F442';
        DeviceIDWord : $04A0;
        ProgramMemorySize : 16384;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : PollWRbit;
        PanelNum : 2;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F452';
        DeviceIDWord : $0420;
        ProgramMemorySize : 32768;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : PollWRbit;
        PanelNum : 4;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F248';
        DeviceIDWord : $0800;
        ProgramMemorySize : 16384;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : PollWRbit;
        PanelNum : 2;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F258';
        DeviceIDWord : $0840;
        ProgramMemorySize : 32768;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : PollWRbit;
        PanelNum : 4;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F448';
        DeviceIDWord : $0820;
        ProgramMemorySize : 16384;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : PollWRbit;
        PanelNum : 2;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F458';
        DeviceIDWord : $0860;
        ProgramMemorySize : 32768;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$27,$0F,$0F,$00,$01,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : PollWRbit;
        PanelNum : 4;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F1220';
        DeviceIDWord : $07E0;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$CF,$0F,$1F,$00,$80,$85,$00,$03,$C0,$03,$E0,$03,$40);
        ConfigValue : ($00,$CF,$0F,$1F,$00,$80,$85,$00,$03,$C0,$03,$E0,$03,$40);
        EraseCommand : Command80;
        EEWriteType : FixWaitTime;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F1320';
        DeviceIDWord : $07C0;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$CF,$0F,$1F,$00,$80,$85,$00,$03,$C0,$03,$E0,$03,$40);
        ConfigValue : ($00,$CF,$0F,$1F,$00,$80,$85,$00,$03,$C0,$03,$E0,$03,$40);
        EraseCommand : Command80;
        EEWriteType : FixWaitTime;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F2220';
        DeviceIDWord : $0580;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$CF,$0F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$CF,$0F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : FixWaitTime;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F2320';
        DeviceIDWord : $0500;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$CF,$0F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$CF,$0F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : FixWaitTime;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F4220';
        DeviceIDWord : $05A0;
        ProgramMemorySize : 4096;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$CF,$0F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$CF,$0F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : FixWaitTime;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F4320';
        DeviceIDWord : $0520;
        ProgramMemorySize : 8192;
        EEDataMemorySize : 256;
        WriteBufferSize : 8;
        ConfigMask : ($00,$CF,$0F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$CF,$0F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command80;
        EEWriteType : FixWaitTime;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F2450';
        DeviceIDWord : $2420;
        ProgramMemorySize : 16384;
        EEDataMemorySize : 0;
        WriteBufferSize : 16;
        ConfigMask : ($3F,$CF,$3F,$1F,$00,$86,$ED,$00,$03,$40,$03,$60,$03,$40);
        ConfigValue : ($00,$05,$1F,$1F,$00,$82,$85,$00,$03,$40,$03,$60,$03,$40);
        EraseCommand : Command3F8F;
        EEWriteType : PollWRbit;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F2455';
        DeviceIDWord : $1260;
        ProgramMemorySize : 24576;
        EEDataMemorySize : 256;
        WriteBufferSize : 32;
        ConfigMask : ($3F,$CF,$3F,$1F,$00,$87,$E5,$00,$07,$C0,$07,$E0,$07,$40);
        ConfigValue : ($00,$05,$1F,$1F,$00,$83,$85,$00,$07,$C0,$07,$E0,$07,$40);
        EraseCommand : Command3F8F;
        EEWriteType : PollWRbit;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F2550';
        DeviceIDWord : $1240;
        ProgramMemorySize : 32768;
        EEDataMemorySize : 256;
        WriteBufferSize : 32;
        ConfigMask : ($3F,$CF,$3F,$1F,$00,$87,$E5,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$05,$1F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command3F8F;
        EEWriteType : PollWRbit;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F4450';
        DeviceIDWord : $2400;
        ProgramMemorySize : 16384;
        EEDataMemorySize : 0;
        WriteBufferSize : 16;
        ConfigMask : ($3F,$CF,$3F,$1F,$00,$86,$ED,$00,$03,$40,$03,$60,$03,$40);
        ConfigValue : ($00,$05,$1F,$1F,$00,$82,$85,$00,$03,$40,$03,$60,$03,$40);
        EraseCommand : Command3F8F;
        EEWriteType : PollWRbit;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F4455';
        DeviceIDWord : $1220;
        ProgramMemorySize : 24576;
        EEDataMemorySize : 256;
        WriteBufferSize : 32;
        ConfigMask : ($3F,$CF,$3F,$1F,$00,$87,$E5,$00,$07,$C0,$07,$E0,$07,$40);
        ConfigValue : ($00,$05,$1F,$1F,$00,$83,$85,$00,$07,$C0,$07,$E0,$07,$40);
        EraseCommand : Command3F8F;
        EEWriteType : PollWRbit;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100),
        (
        DeviceName : 'PIC18F4550';
        DeviceIDWord : $1200;
        ProgramMemorySize : 32768;
        EEDataMemorySize : 256;
        WriteBufferSize : 32;
        ConfigMask : ($3F,$CF,$3F,$1F,$00,$87,$E5,$00,$0F,$C0,$0F,$E0,$0F,$40);
        ConfigValue : ($00,$05,$1F,$1F,$00,$83,$85,$00,$0F,$C0,$0F,$E0,$0F,$40);
        EraseCommand : Command3F8F;
        EEWriteType : PollWRbit;
        PanelNum : 1;
        PanelSize : 8192;
        ProgrammingWaitP : 10;
        ProgrammingWaitD : 50;
        ProgrammingWaitC : 50;
        ProgrammingWaitID : 50;
        EraseWait : 100)
    );

implementation

end.
